pub enum FramePointerUse {
None,
WithRecords,
WithoutRecords,
Unknown(u8),
}Variants
None
The code does not conform to the rules of using the frame pointer.
WithRecords
The code creates a frame record for all functions that can modify the link register (LR).
WithoutRecords
The codes does not create records, but preserves the frame pointer register (FP) value.
Unknown(u8)
Implementations